###--- >>> `housing' <<<----- Frequency Table from a Copenhagen Housing Conditions Survey.

	## alias	 help(housing)

##___ Examples ___:

data(housing)
options(contrasts=c("contr.treatment", "contr.poly"))

# Surrogate Poisson models
house.glm0 <- glm(Freq ~ Infl*Type*Cont + Sat, family=poisson, 
                   data=housing)
summary(house.glm0, cor=FALSE)

addterm(house.glm0, ~. + Sat:(Infl+Type+Cont), test="Chisq")

house.glm1 <- update(house.glm0, . ~ . + Sat*(Infl+Type+Cont))
summary(house.glm1, cor=FALSE)

1 - pchisq(deviance(house.glm1), house.glm1$df.resid)

dropterm(house.glm1, test="Chisq")

addterm(house.glm1, ~. + Sat:(Infl+Type+Cont)^2, test = "Chisq")

hnames <- lapply(housing[, -5], levels) # omit Freq
house.pm <- predict(house.glm1, expand.grid(hnames),
                   type = "response")  # poisson means
house.pm <- matrix(house.pm, ncol=3, byrow=TRUE, 
                  dimnames=list(NULL, hnames[[1]]))
house.pr <- house.pm/drop(house.pm %*% rep(1, 3))
cbind(expand.grid(hnames[-1]), round(house.pr, 2))

# Iterative proportional scaling
loglm(Freq ~ Infl*Type*Cont + Sat*(Infl+Type+Cont), data=housing)

# multinomial model
library(nnet)
house.mult<- multinom(Sat ~ Infl + Type + Cont, weights=Freq,
                       data=housing)
house.mult
house.mult2 <- multinom(Sat ~ Infl*Type*Cont, weights=Freq,
                         data=housing)
anova(house.mult, house.mult2)

house.pm <- predict(house.mult, expand.grid(hnames[-1]),
                    type = "probs")
cbind(expand.grid(hnames[-1]), round(house.pm, 2))

##Don't run: 
##D # proportional odds model
##D house.cpr <- apply(house.pr, 1, cumsum)
##D logit <- function(x) log(x/(1-x))
##D house.ld <- logit(house.cpr[2, ]) - logit(house.cpr[1, ])
##D sort(drop(house.ld))
##D mean(.Last.value)
##D 
##D house.plr <- polr(Sat ~ Infl + Type + Cont, 
##D                data = housing, weights = Freq)
##D house.plr
##D 
##D house.pr1 <- predict(house.plr, expand.grid(hnames[-1]),
##D                    type = "probs")
##D cbind(expand.grid(hnames[-1]), round(house.pr1, 2))
##D 
##D Fr <- matrix(housing$Freq, ncol = 3, byrow=TRUE)
##D 2*sum(Fr*log(house.pr/house.pr1))
##D 
##D house.plr2 <- stepAIC(house.plr, ~.^2)
##D house.plr2$anova


## Keywords: 'datasets'.


